chicken_turtle_util.series
==========================

.. automodule:: chicken_turtle_util.series

.. autosummary::
   :nosignatures:

   assert_equals
   equals
   invert
   split

.. autofunction:: assert_equals
.. autofunction:: equals
.. autofunction:: invert
.. autofunction:: split
